!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! Test driver for stringfast module: outputs TT, BB, EE power spectra
!  in text files at specified values of string parameters and optical
!  depth
!
!     **REMEMBER: the output format for C_l values is
!                 [l(l+1)/2pi] C_l (muK^2)
!  
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!


program driver
  use stringfast
  implicit none
  integer :: ell
  ! Parameters of strings, plus optical depth of background cosmology
  real(8), parameter :: od             = 0.088d0
  real(8), parameter :: gmu            = 6.4d-7
  real(8), parameter :: alpha          = 1.05d0
  real(8), parameter :: vel            = 0.40d0
  real(8), parameter :: cl             = 0.35d0
  ! Output files
  character(LEN=8) :: ttfname= 'cls_tt.d'
  character(LEN=8) :: eefname= 'cls_ee.d'
  character(LEN=8) :: bbfname= 'cls_bb.d'


  ! Load grid into memory
  call SF_setuptt(1)
  call SF_setuptt(2)
  call SF_setuptt(3)
  call SF_setupbb(2)
  call SF_setupbb(3)
  call SF_setupee(1)
  call SF_setupee(2)
  call SF_setupee(3)

  ! Write file with TT scalar, vector, tensor C_ls
  open(unit=75,file=ttfname,status='unknown')
  do ell=2,2999
    write(75,'(I6,3E16.6)') ell,SF_ttcalc(1,gmu,od,alpha,vel,cl,ell), &
                              	SF_ttcalc(2,gmu,od,alpha,vel,cl,ell), &
                              	SF_ttcalc(3,gmu,od,alpha,vel,cl,ell)
  end do
  close(75)
  
  ! Write file with BB vector, tensor C_ls
  open(unit=75,file=bbfname,status='unknown')
  do ell=2,2999
    write(75,'(I6,3E16.6)') ell,SF_bbcalc(2,gmu,od,alpha,vel,cl,ell), &
                              	SF_bbcalc(3,gmu,od,alpha,vel,cl,ell)
  end do
  close(75)
  
  ! Write file with EE scalar, vector, tensor C_ls
  open(unit=75,file=eefname,status='unknown')
  do ell=2,2999
    write(75,'(I6,3E16.6)') ell,SF_eecalc(1,gmu,od,alpha,vel,cl,ell), &
                                SF_eecalc(2,gmu,od,alpha,vel,cl,ell), &
                                SF_eecalc(3,gmu,od,alpha,vel,cl,ell)
  end do
  close(75)
  
  ! Deallocate memory used by module
  call SF_finishtt()
  call SF_finishbb()
  call SF_finishee()

end program driver
